

Utilities
====================

This utility script calculates entropy production rate and exergy loss rates,
but specifically for adiabatic heat pumps or heat exchangers, only. It is
used by the heat_pump_simple.py script.

It is found at: src.utils.exergy_loss


.. automodule:: src.utils.exergy_loss
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:
    

.. automodule:: src.utils.curve_min_distance_finder
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:



Helpers
====================

Some helper functions, found at src\\helpers
Here for copying all results and the source py-file to a new directory.


.. automodule:: src.helpers.file_copy
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members: